@@ -10,7 +10,7 @@ from __future__ import annotations
 import weakref
 from asyncio import Task, sleep
 from collections import deque
-from typing import TYPE_CHECKING, Any, Deque, Generator
+from typing import TYPE_CHECKING, Any, Generator
 
 from prompt_toolkit.application.current import get_app
 from prompt_toolkit.enums import EditingMode
@@ -103,7 +103,7 @@ class KeyProcessor:
         self._previous_handler: Binding | None = None
 
         # The queue of keys not yet send to our _process generator/state machine.
-        self.input_queue: Deque[KeyPress] = deque()
+        self.input_queue: deque[KeyPress] = deque()
 
         # The key buffer that is matched in the generator state machine.
         # (This is at at most the amount of keys that make up for one key binding.)
